==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/tanda_jasa_response.dart <==
class TandaJasaResponse {
  bool con;
  String msg;
  List<TandaJasaResults> results;

  TandaJasaResponse({this.con, this.msg, this.results});

  TandaJasaResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <TandaJasaResults>[];
      json['results'].forEach((v) {
        results.add(TandaJasaResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class TandaJasaResults {
  int id;
  String nip;
  String skNomor;
  String skTanggal;
  String namaTandaJasa;
  String tahun;
  String asalPerolehan;
  String documen;
  String pathFile;

  TandaJasaResults(
      {this.id,
      this.nip,
      this.skNomor,
      this.skTanggal,
      this.namaTandaJasa,
      this.tahun,
      this.asalPerolehan,
      this.documen,
      this.pathFile});

  TandaJasaResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nip = json['nip'];
    skNomor = json['sk_nomor'];
    skTanggal = json['sk_tanggal'];
    namaTandaJasa = json['nama_tanda_jasa'];
    tahun = json['tahun'];
    asalPerolehan = json['asal_perolehan'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nip'] = this.nip;
    data['sk_nomor'] = this.skNomor;
    data['sk_tanggal'] = this.skTanggal;
    data['nama_tanda_jasa'] = this.namaTandaJasa;
    data['tahun'] = this.tahun;
    data['asal_perolehan'] = this.asalPerolehan;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.1.5.tar.gz: lib/msimpersaa/response/tanda_jasa_response.dart <==
class TandaJasaResponse {
  bool con;
  String msg;
  List<TandaJasaResults> results;

  TandaJasaResponse({this.con, this.msg, this.results});

  TandaJasaResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <TandaJasaResults>[];
      json['results'].forEach((v) {
        results.add(TandaJasaResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class TandaJasaResults {
  int id;
  String nip;
  String skNomor;
  String skTanggal;
  String namaTandaJasa;
  String tahun;
  String asalPerolehan;
  String document;
  String pathFile;

  TandaJasaResults(
      {this.id,
      this.nip,
      this.skNomor,
      this.skTanggal,
      this.namaTandaJasa,
      this.tahun,
      this.asalPerolehan,
      this.document,
      this.pathFile});

  TandaJasaResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nip = json['nip'];
    skNomor = json['sk_nomor'];
    skTanggal = json['sk_tanggal'];
    namaTandaJasa = json['nama_tanda_jasa'];
    tahun = json['tahun'];
    asalPerolehan = json['asal_perolehan'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nip'] = this.nip;
    data['sk_nomor'] = this.skNomor;
    data['sk_tanggal'] = this.skTanggal;
    data['nama_tanda_jasa'] = this.namaTandaJasa;
    data['tahun'] = this.tahun;
    data['asal_perolehan'] = this.asalPerolehan;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
